<?php

namespace Drupal\cmood\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\node\Entity\NodeType;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class CmoodSettingsForm implements a config form for cmood admin settings.
 */
class CmoodSettingsForm extends ConfigFormBase {

  /**
   * @inheritDoc
   */
  public function getFormId() {
    return 'cmood_settings_form';
  }

  /**
   * @inheritDoc
   */
  public function buildForm(array $form, FormStateInterface $form_state, Request $request = NULL) {
    $form = array();
    $form['node_type'] = array(
      '#type' => 'fieldset',
      '#title' => t('Content types'),
      '#description' => t('Choose the content type for which you want to enable Cmood.'),
    );

    $form['node_type']['cmood_enabled_types'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Calculate mood for content types:'),
      '#default_value' => \Drupal::config('cmood.settings')->get('cmood_enabled_types'),
      '#options' => node_type_get_names(),
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * @inheritDoc
   */
  protected function getEditableConfigNames() {
    return ['cmood.settings'];
  }

  /**
   * @inheritDoc
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $userInputValues = $form_state->getUserInput();
    $config = $this->configFactory->getEditable('cmood.settings');
    $config->set('cmood_enabled_types', $userInputValues['cmood_enabled_types']);
    $config->save();
    parent::submitForm($form, $form_state);
  }

}
